%global gst_version 1.22.5

Name:           gstreamer1-plugin-openh264
Version:        1.22.5
Release:        1%{?dist}
Summary:        GStreamer OpenH264 plugin

License:        LGPL-2.0-or-later AND BSD-2-Clause
URL:            https://www.openh264.org/
# The source is:
# http://gstreamer.freedesktop.org/src/gst-plugins-bad/gst-plugins-bad-%%{gst_version}.tar.xz
# modified with gst-p-bad-cleanup.sh from SOURCE1
Source0:        gst-plugins-bad-openh264-%{gst_version}.tar.xz
Source1:        gst-p-bad-cleanup.sh

# Fail gracefully if noopenh264 is used
# https://gitlab.freedesktop.org/gstreamer/gstreamer/-/merge_requests/5581
Patch:          graceful-error-noopenh264.patch
# https://gitlab.freedesktop.org/gstreamer/gstreamer/-/merge_requests/5622
Patch:          openh264-add-license-file.patch

BuildRequires:  gcc-c++
BuildRequires:  gstreamer1-devel >= %{gst_version}
BuildRequires:  gstreamer1-plugins-base-devel >= %{gst_version}
BuildRequires:  meson
BuildRequires:  nasm
BuildRequires:  pkgconfig(openh264)

# Prefer actual openh264 library over the noopenh264 stub
Suggests:       openh264

%description
GStreamer is a streaming media framework, based on graphs of elements which
operate on media data.

This package contains the OpenH264 plugin.


%prep
%autosetup -p3 -n gst-plugins-bad-%{version}


%build
%meson \
    --auto-features=disabled \
    -D package-name="Fedora gstreamer1-plugin-openh264 package" \
    -D package-origin="http://download.fedoraproject.org" \
    -D openh264=enabled
%meson_build


%install
%meson_install

# Register as an AppStream component to be visible in the software center
#
# NOTE: It would be *awesome* if this file was maintained by the upstream
# project, translated and installed into the right place during `make install`.
#
# See http://www.freedesktop.org/software/appstream/docs/ for more details.
#
mkdir -p $RPM_BUILD_ROOT%{_metainfodir}
cat > $RPM_BUILD_ROOT%{_metainfodir}/gstreamer-openh264.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright 2015 Kalev Lember <klember@redhat.com> -->
<component type="codec">
  <id>gstreamer-openh264</id>
  <metadata_license>CC0-1.0</metadata_license>
  <name>GStreamer Multimedia Codecs - H.264</name>
  <summary>Multimedia playback for H.264</summary>
  <description>
    <p>
      This addon includes a codec for H.264 playback and encoding.
    </p>
    <p>
      These codecs can be used to encode and decode media files where the
      format is not patent encumbered.
    </p>
    <p>
      A codec decodes audio and video for playback or editing and is also
      used for transmission or storage.
      Different codecs are used in video-conferencing, streaming media and
      video editing applications.
    </p>
  </description>
  <url type="homepage">http://gstreamer.freedesktop.org/</url>
  <url type="bugtracker">https://bugzilla.gnome.org/enter_bug.cgi?product=GStreamer</url>
  <url type="help">http://gstreamer.freedesktop.org/documentation/</url>
  <url type="donation">http://www.gnome.org/friends/</url>
  <update_contact><!-- upstream-contact_at_email.com --></update_contact>
</component>
EOF

# Remove unwanted gst-plugins-bad files
rm -rf $RPM_BUILD_ROOT%{_bindir}/gst-transcoder-1.0
rm -rf $RPM_BUILD_ROOT%{_includedir}/gstreamer-1.0/
rm -rf $RPM_BUILD_ROOT%{_libdir}/pkgconfig/gstreamer-*.pc
rm -rf $RPM_BUILD_ROOT%{_libdir}/libgst*.so*
rm -rf $RPM_BUILD_ROOT%{_datadir}/gstreamer-1.0/


%files
%license COPYING
%license ext/openh264/LICENSE
%{_metainfodir}/*.appdata.xml
%{_libdir}/gstreamer-1.0/libgstopenh264.so


%changelog
* Thu Nov 09 2023 Kalev Lember <klember@redhat.com> - 1.22.5-1
- Update to 1.22.5

* Tue Oct 31 2023 Kalev Lember <klember@redhat.com> - 1.22.1-1
- Initial Fedora packaging
